#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=kurikoma2.17_base.ps
projection=-JM16.0c+
region=-R140.1/141.9/38.1/39.4
gmt psbasemap $region $projection -Bxa0.5f0.1 -Bya0.5f0.1 -BWeSn+t'Base Map kurikoma2.17' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    38.726   141.138
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    38.722   141.140
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    38.730   141.175
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    38.727   141.145
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    38.707   141.132
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    38.733   141.180
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    38.691   141.136
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    38.685   141.075
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    39.229   140.716
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    39.280   140.722
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    39.251   140.829
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    38.719   141.122
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    38.687   140.651
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    38.776   140.804
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    38.681   141.156
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    38.690   141.199
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    38.160   140.829
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    38.772   140.687
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    38.774   141.030
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    38.567   141.763
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    38.715   141.080
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    38.727   141.193
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    38.977   140.459
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    38.421   140.667
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    38.963   141.007
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    38.993   140.972
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    38.891   140.723
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    38.887   140.736
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    38.773   141.125
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    39.052   140.953
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    39.055   140.958
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    39.001   140.961
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    38.766   141.146
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    38.297   140.831
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    38.311   140.535
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    38.803   141.207
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    38.938   140.649
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    38.955   141.002
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    38.694   141.067
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    38.671   141.115
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    38.823   140.738
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    38.829   140.748
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    38.491   140.346
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    38.768   141.172
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    38.838   141.031
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    38.479   140.819
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    39.043   140.971
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    38.874   140.843
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    38.886   140.821
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    38.879   140.841
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    38.880   140.823
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    38.829   140.617
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    38.868   140.640
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    38.870   140.640
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    38.828   140.642
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    38.876   140.639
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    38.889   140.621
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    38.874   140.657
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    38.894   140.655
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    38.846   140.634
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    38.937   140.679
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    38.906   140.619
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    38.880   140.650
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    38.856   140.628
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    38.869   140.647
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    38.902   140.610
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    38.834   140.644
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    38.858   140.633
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    38.848   140.642
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    38.889   140.646
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    38.862   140.687
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    38.820   140.644
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    38.828   140.645
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    38.836   140.633
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    38.816   140.649
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    38.857   140.679
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    38.907   140.683
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    38.867   140.672
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    38.884   140.666
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    38.950   140.581
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    38.883   140.663
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    38.959   140.572
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    38.960   140.574
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    38.813   140.585
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    38.807   140.592
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    38.909   140.618
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    38.810   140.588
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    38.896   140.624
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    38.893   140.645
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    38.902   140.633
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    38.865   140.674
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    38.888   140.651
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    38.888   140.675
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    38.865   140.644
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    38.888   140.613
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    38.850   140.694
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    38.887   141.024
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    38.271   140.767
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    38.290   140.752
END
gmt psxy -: -R $projection -Sl8p+t"100" -G0 -O -K << END >> $psfile
    38.274   140.768
END
gmt psxy -: -R $projection -Sl8p+t"101" -G0 -O -K << END >> $psfile
    38.785   140.728
END
gmt psxy -: -R $projection -Sl8p+t"102" -G0 -O -K << END >> $psfile
    38.282   140.769
END
gmt psxy -: -R $projection -Sl8p+t"103" -G0 -O -K << END >> $psfile
    39.019   140.933
END
gmt psxy -: -R $projection -Sl8p+t"104" -G0 -O -K << END >> $psfile
    38.875   141.026
END
gmt psxy -: -R $projection -Sl8p+t"105" -G0 -O -K << END >> $psfile
    38.874   140.682
END
gmt psxy -: -R $projection -Sl8p+t"106" -G0 -O -K << END >> $psfile
    39.024   140.924
END
gmt psxy -: -R $projection -Sl8p+t"107" -G0 -O -K << END >> $psfile
    39.018   140.925
END
gmt psxy -: -R $projection -Sl8p+t"108" -G0 -O -K << END >> $psfile
    39.022   140.915
END
gmt psxy -: -R $projection -Sl8p+t"109" -G0 -O -K << END >> $psfile
    38.983   140.965
END
gmt psxy -: -R $projection -Sl8p+t"110" -G0 -O -K << END >> $psfile
    38.758   140.701
END
gmt psxy -: -R $projection -Sl8p+t"111" -G0 -O -K << END >> $psfile
    38.609   141.144
END
gmt psxy -: -R $projection -Sl8p+t"112" -G0 -O -K << END >> $psfile
    38.770   141.128
END
gmt psxy -: -R $projection -Sl8p+t"113" -G0 -O -K << END >> $psfile
    38.714   141.134
END
gmt psxy -: -R $projection -Sl8p+t"114" -G0 -O -K << END >> $psfile
    38.472   140.530
END
gmt psxy -: -R $projection -Sl8p+t"115" -G0 -O -K << END >> $psfile
    39.045   140.978
END
gmt psxy -: -R $projection -Sl8p+t"116" -G0 -O -K << END >> $psfile
    38.435   141.162
END
gmt psxy -: -R $projection -Sl8p+t"117" -G0 -O -K << END >> $psfile
    38.397   141.155
END
gmt psxy -: -R $projection -Sl8p+t"118" -G0 -O -K << END >> $psfile
    38.426   141.165
END
gmt psxy -: -R $projection -Sl8p+t"119" -G0 -O -K << END >> $psfile
    38.469   141.165
END
gmt psxy -: -R $projection -Sl8p+t"120" -G0 -O -K << END >> $psfile
    38.471   141.166
END
gmt psxy -: -R $projection -Sl8p+t"121" -G0 -O -K << END >> $psfile
    38.420   141.201
END
gmt psxy -: -R $projection -Sl8p+t"122" -G0 -O -K << END >> $psfile
    38.485   141.177
END
gmt psxy -: -R $projection -Sl8p+t"123" -G0 -O -K << END >> $psfile
    38.469   141.187
END
gmt psxy -: -R $projection -Sl8p+t"124" -G0 -O -K << END >> $psfile
    38.478   141.222
END
gmt psxy -: -R $projection -Sl8p+t"125" -G0 -O -K << END >> $psfile
    38.473   141.168
END
gmt psxy -: -R $projection -Sl8p+t"126" -G0 -O -K << END >> $psfile
    38.476   141.159
END
gmt psxy -: -R $projection -Sl8p+t"127" -G0 -O -K << END >> $psfile
    38.428   141.194
END
gmt psxy -: -R $projection -Sl8p+t"128" -G0 -O -K << END >> $psfile
    38.497   141.207
END
gmt psxy -: -R $projection -Sl8p+t"129" -G0 -O -K << END >> $psfile
    38.508   141.186
END
gmt psxy -: -R $projection -Sl8p+t"130" -G0 -O -K << END >> $psfile
    38.486   141.212
END
gmt psxy -: -R $projection -Sl8p+t"131" -G0 -O -K << END >> $psfile
    38.474   141.169
END
gmt psxy -: -R $projection -Sl8p+t"132" -G0 -O -K << END >> $psfile
    38.392   141.171
END
gmt psxy -: -R $projection -Sl8p+t"133" -G0 -O -K << END >> $psfile
    38.530   141.229
END
gmt psxy -: -R $projection -Sl8p+t"134" -G0 -O -K << END >> $psfile
    38.463   141.177
END
gmt psxy -: -R $projection -Sl8p+t"135" -G0 -O -K << END >> $psfile
    38.507   141.180
END
gmt psxy -: -R $projection -Sl8p+t"136" -G0 -O -K << END >> $psfile
    39.049   140.975
END
gmt psxy -: -R $projection -Sl8p+t"137" -G0 -O -K << END >> $psfile
    38.474   141.163
END
gmt psxy -: -R $projection -Sl8p+t"138" -G0 -O -K << END >> $psfile
    38.493   141.192
END
gmt psxy -: -R $projection -Sl8p+t"139" -G0 -O -K << END >> $psfile
    38.390   141.168
END
gmt psxy -: -R $projection -Sl8p+t"140" -G0 -O -K << END >> $psfile
    38.461   141.215
END
gmt psxy -: -R $projection -Sl8p+t"141" -G0 -O -K << END >> $psfile
    39.083   140.850
END
gmt psxy -: -R $projection -Sl8p+t"142" -G0 -O -K << END >> $psfile
    38.975   140.627
END
gmt psxy -: -R $projection -Sl8p+t"143" -G0 -O -K << END >> $psfile
    38.392   140.749
END
gmt psxy -: -R $projection -Sl8p+t"144" -G0 -O -K << END >> $psfile
    38.202   141.173
END
gmt psxy -: -R $projection -Sl8p+t"145" -G0 -O -K << END >> $psfile
    38.200   141.154
END
gmt psxy -: -R $projection -Sl8p+t"146" -G0 -O -K << END >> $psfile
    38.422   141.123
END
gmt psxy -: -R $projection -Sl8p+t"147" -G0 -O -K << END >> $psfile
    38.985   140.600
END
gmt psxy -: -R $projection -Sl8p+t"148" -G0 -O -K << END >> $psfile
    39.047   140.876
END
gmt psxy -: -R $projection -Sl8p+t"149" -G0 -O -K << END >> $psfile
    39.117   140.957
END
gmt psxy -: -R $projection -Sl8p+t"150" -G0 -O -K << END >> $psfile
    39.113   141.039
END
gmt psxy -: -R $projection -Sl8p+t"151" -G0 -O -K << END >> $psfile
    39.144   140.954
END
gmt psxy -: -R $projection -Sl8p+t"152" -G0 -O -K << END >> $psfile
    38.901   140.905
END
gmt psxy -: -R $projection -Sl8p+t"153" -G0 -O -K << END >> $psfile
    39.017   140.887
END
gmt psxy -: -R $projection -Sl8p+t"154" -G0 -O -K << END >> $psfile
    39.107   140.901
END
gmt psxy -: -R $projection -Sl8p+t"155" -G0 -O -K << END >> $psfile
    38.821   140.833
END
gmt psxy -: -R $projection -Sl8p+t"156" -G0 -O -K << END >> $psfile
    39.143   140.944
END
gmt psxy -: -R $projection -Sl8p+t"157" -G0 -O -K << END >> $psfile
    38.896   140.703
END
gmt psxy -: -R $projection -Sl8p+t"158" -G0 -O -K << END >> $psfile
    39.030   140.897
END
gmt psxy -: -R $projection -Sl8p+t"159" -G0 -O -K << END >> $psfile
    38.905   140.739
END
gmt psxy -: -R $projection -Sl8p+t"160" -G0 -O -K << END >> $psfile
    39.092   140.948
END
gmt psxy -: -R $projection -Sl8p+t"161" -G0 -O -K << END >> $psfile
    39.125   140.978
END
gmt psxy -: -R $projection -Sl8p+t"162" -G0 -O -K << END >> $psfile
    39.043   140.941
END
gmt psxy -: -R $projection -Sl8p+t"163" -G0 -O -K << END >> $psfile
    38.909   140.892
END
gmt psxy -: -R $projection -Sl8p+t"164" -G0 -O -K << END >> $psfile
    39.070   141.037
END
gmt psxy -: -R $projection -Sl8p+t"165" -G0 -O -K << END >> $psfile
    39.088   140.905
END
gmt psxy -: -R $projection -Sl8p+t"166" -G0 -O -K << END >> $psfile
    39.078   141.011
END
gmt psxy -: -R $projection -Sl8p+t"167" -G0 -O -K << END >> $psfile
    39.102   140.891
END
gmt psxy -: -R $projection -Sl8p+t"168" -G0 -O -K << END >> $psfile
    39.028   140.909
END
gmt psxy -: -R $projection -Sl8p+t"169" -G0 -O -K << END >> $psfile
    39.107   140.954
END
gmt psxy -: -R $projection -Sl8p+t"170" -G0 -O -K << END >> $psfile
    38.940   140.910
END
gmt psxy -: -R $projection -Sl8p+t"171" -G0 -O -K << END >> $psfile
    39.108   140.956
END
gmt psxy -: -R $projection -Sl8p+t"172" -G0 -O -K << END >> $psfile
    38.871   140.894
END
gmt psxy -: -R $projection -Sl8p+t"173" -G0 -O -K << END >> $psfile
    38.879   140.887
END
gmt psxy -: -R $projection -Sl8p+t"174" -G0 -O -K << END >> $psfile
    39.104   140.917
END
gmt psxy -: -R $projection -Sl8p+t"175" -G0 -O -K << END >> $psfile
    39.060   140.972
END
gmt psxy -: -R $projection -Sl8p+t"176" -G0 -O -K << END >> $psfile
    39.140   140.967
END
gmt psxy -: -R $projection -Sl8p+t"177" -G0 -O -K << END >> $psfile
    38.999   140.932
END
gmt psxy -: -R $projection -Sl8p+t"178" -G0 -O -K << END >> $psfile
    39.096   140.888
END
gmt psxy -: -R $projection -Sl8p+t"179" -G0 -O -K << END >> $psfile
    39.059   140.882
END
gmt psxy -: -R $projection -Sl8p+t"180" -G0 -O -K << END >> $psfile
    39.109   140.951
END
gmt psxy -: -R $projection -Sl8p+t"181" -G0 -O -K << END >> $psfile
    39.117   140.965
END
gmt psxy -: -R $projection -Sl8p+t"182" -G0 -O -K << END >> $psfile
    38.973   140.916
END
gmt psxy -: -R $projection -Sl8p+t"183" -G0 -O -K << END >> $psfile
    39.108   140.975
END
gmt psxy -: -R $projection -Sl8p+t"184" -G0 -O -K << END >> $psfile
    39.142   140.943
END
gmt psxy -: -R $projection -Sl8p+t"185" -G0 -O -K << END >> $psfile
    38.860   140.883
END
gmt psxy -: -R $projection -Sl8p+t"186" -G0 -O -K << END >> $psfile
    38.871   140.785
END
gmt psxy -: -R $projection -Sl8p+t"187" -G0 -O -K << END >> $psfile
    39.127   140.928
END
gmt psxy -: -R $projection -Sl8p+t"188" -G0 -O -K << END >> $psfile
    39.124   140.934
END
gmt psxy -: -R $projection -Sl8p+t"189" -G0 -O -K << END >> $psfile
    38.896   140.787
END
gmt psxy -: -R $projection -Sl8p+t"190" -G0 -O -K << END >> $psfile
    39.149   140.955
END
gmt psxy -: -R $projection -Sl8p+t"191" -G0 -O -K << END >> $psfile
    38.977   140.958
END
gmt psxy -: -R $projection -Sl8p+t"192" -G0 -O -K << END >> $psfile
    39.013   140.967
END
gmt psxy -: -R $projection -Sl8p+t"193" -G0 -O -K << END >> $psfile
    39.086   140.999
END
gmt psxy -: -R $projection -Sl8p+t"194" -G0 -O -K << END >> $psfile
    38.878   140.791
END
gmt psxy -: -R $projection -Sl8p+t"195" -G0 -O -K << END >> $psfile
    39.156   140.878
END
gmt psxy -: -R $projection -Sl8p+t"196" -G0 -O -K << END >> $psfile
    39.159   140.969
END
gmt psxy -: -R $projection -Sl8p+t"197" -G0 -O -K << END >> $psfile
    38.788   140.807
END
gmt psxy -: -R $projection -Sl8p+t"198" -G0 -O -K << END >> $psfile
    38.755   140.798
END
gmt psxy -: -R $projection -Sl8p+t"199" -G0 -O -K << END >> $psfile
    39.126   140.932
END
gmt psxy -: -R $projection -Sl8p+t"200" -G0 -O -K << END >> $psfile
    39.165   140.986
END
gmt psxy -: -R $projection -Sl8p+t"201" -G0 -O -K << END >> $psfile
    39.129   140.923
END
gmt psxy -: -R $projection -Sl8p+t"202" -G0 -O -K << END >> $psfile
    39.145   140.969
END
gmt psxy -: -R $projection -Sl8p+t"203" -G0 -O -K << END >> $psfile
    39.105   140.944
END
gmt psxy -: -R $projection -Sl8p+t"204" -G0 -O -K << END >> $psfile
    39.127   140.947
END
gmt psxy -: -R $projection -Sl8p+t"205" -G0 -O -K << END >> $psfile
    39.158   140.960
END
gmt psxy -: -R $projection -Sl8p+t"206" -G0 -O -K << END >> $psfile
    39.186   140.977
END
gmt psxy -: -R $projection -Sl8p+t"207" -G0 -O -K << END >> $psfile
    38.987   140.791
END
gmt psxy -: -R $projection -Sl8p+t"208" -G0 -O -K << END >> $psfile
    38.914   140.871
END
gmt psxy -: -R $projection -Sl8p+t"209" -G0 -O -K << END >> $psfile
    39.060   140.803
END
gmt psxy -: -R $projection -Sl8p+t"210" -G0 -O -K << END >> $psfile
    39.088   140.963
END
gmt psxy -: -R $projection -Sl8p+t"211" -G0 -O -K << END >> $psfile
    39.134   140.966
END
gmt psxy -: -R $projection -Sl8p+t"212" -G0 -O -K << END >> $psfile
    39.153   140.959
END
gmt psxy -: -R $projection -Sl8p+t"213" -G0 -O -K << END >> $psfile
    38.791   140.801
END
gmt psxy -: -R $projection -Sl8p+t"214" -G0 -O -K << END >> $psfile
    38.902   140.591
END
gmt psxy -: -R $projection -Sl8p+t"215" -G0 -O -K << END >> $psfile
    38.834   140.846
END
gmt psxy -: -R $projection -Sl8p+t"216" -G0 -O -K << END >> $psfile
    39.103   140.968
END
gmt psxy -: -R $projection -Sl8p+t"217" -G0 -O -K << END >> $psfile
    39.167   140.984
END
gmt psxy -: -R $projection -Sl8p+t"218" -G0 -O -K << END >> $psfile
    39.043   140.891
END
gmt psxy -: -R $projection -Sl8p+t"219" -G0 -O -K << END >> $psfile
    39.100   140.947
END
gmt psxy -: -R $projection -Sl8p+t"220" -G0 -O -K << END >> $psfile
    39.046   140.910
END
gmt psxy -: -R $projection -Sl8p+t"221" -G0 -O -K << END >> $psfile
    39.164   140.974
END
gmt psxy -: -R $projection -Sl8p+t"222" -G0 -O -K << END >> $psfile
    39.171   140.974
END
gmt psxy -: -R $projection -Sl8p+t"223" -G0 -O -K << END >> $psfile
    38.940   140.921
END
gmt psxy -: -R $projection -Sl8p+t"224" -G0 -O -K << END >> $psfile
    39.119   141.006
END
gmt psxy -: -R $projection -Sl8p+t"225" -G0 -O -K << END >> $psfile
    39.038   140.899
END
gmt psxy -: -R $projection -Sl8p+t"226" -G0 -O -K << END >> $psfile
    38.856   140.831
END
gmt psxy -: -R $projection -Sl8p+t"227" -G0 -O -K << END >> $psfile
    39.080   140.975
END
gmt psxy -: -R $projection -Sl8p+t"228" -G0 -O -K << END >> $psfile
    38.749   140.792
END
gmt psxy -: -R $projection -Sl8p+t"229" -G0 -O -K << END >> $psfile
    38.742   140.779
END
gmt psxy -: -R $projection -Sl8p+t"230" -G0 -O -K << END >> $psfile
    38.751   140.762
END
gmt psxy -: -R $projection -Sl8p+t"231" -G0 -O -K << END >> $psfile
    38.734   140.791
END
gmt psxy -: -R $projection -Sl8p+t"232" -G0 -O -K << END >> $psfile
    38.743   140.792
END
gmt psxy -: -R $projection -Sl8p+t"233" -G0 -O -K << END >> $psfile
    38.880   140.757
END
gmt psxy -: -R $projection -Sl8p+t"234" -G0 -O -K << END >> $psfile
    38.949   140.665
END
gmt psxy -: -R $projection -Sl8p+t"235" -G0 -O -K << END >> $psfile
    39.110   140.970
END
gmt psxy -: -R $projection -Sl8p+t"236" -G0 -O -K << END >> $psfile
    39.065   140.968
END
gmt psxy -: -R $projection -Sl8p+t"237" -G0 -O -K << END >> $psfile
    38.874   140.785
END
gmt psxy -: -R $projection -Sl8p+t"238" -G0 -O -K << END >> $psfile
    39.164   140.860
END
gmt psxy -: -R $projection -Sl8p+t"239" -G0 -O -K << END >> $psfile
    39.129   140.915
END
gmt psxy -: -R $projection -Sl8p+t"240" -G0 -O -K << END >> $psfile
    39.111   140.877
END
gmt psxy -: -R $projection -Sl8p+t"241" -G0 -O -K << END >> $psfile
    39.001   140.896
END
gmt psxy -: -R $projection -Sl8p+t"242" -G0 -O -K << END >> $psfile
    38.981   140.841
END
gmt psxy -: -R $projection -Sl8p+t"243" -G0 -O -K << END >> $psfile
    38.955   140.931
END
gmt psxy -: -R $projection -Sl8p+t"244" -G0 -O -K << END >> $psfile
    39.060   140.875
END
gmt psxy -: -R $projection -Sl8p+t"245" -G0 -O -K << END >> $psfile
    39.075   140.818
END
gmt psxy -: -R $projection -Sl8p+t"246" -G0 -O -K << END >> $psfile
    39.057   140.890
END
gmt psxy -: -R $projection -Sl8p+t"247" -G0 -O -K << END >> $psfile
    38.821   140.860
END
gmt psxy -: -R $projection -Sl8p+t"248" -G0 -O -K << END >> $psfile
    39.175   140.853
END
gmt psxy -: -R $projection -Sl8p+t"249" -G0 -O -K << END >> $psfile
    39.129   140.952
END
gmt psxy -: -R $projection -Sl8p+t"250" -G0 -O -K << END >> $psfile
    39.145   140.942
END
gmt psxy -: -R $projection -Sl8p+t"251" -G0 -O -K << END >> $psfile
    39.150   140.883
END
gmt psxy -: -R $projection -Sl8p+t"252" -G0 -O -K << END >> $psfile
    38.892   140.970
END
gmt psxy -: -R $projection -Sl8p+t"253" -G0 -O -K << END >> $psfile
    38.869   140.887
END
gmt psxy -: -R $projection -Sl8p+t"254" -G0 -O -K << END >> $psfile
    38.753   140.804
END
gmt psxy -: -R $projection -Sl8p+t"255" -G0 -O -K << END >> $psfile
    39.053   140.895
END
gmt psxy -: -R $projection -Sl8p+t"256" -G0 -O -K << END >> $psfile
    38.864   140.749
END
gmt psxy -: -R $projection -Sl8p+t"257" -G0 -O -K << END >> $psfile
    38.793   140.791
END
gmt psxy -: -R $projection -Sl8p+t"258" -G0 -O -K << END >> $psfile
    38.898   140.813
END
gmt psxy -: -R $projection -Sl8p+t"259" -G0 -O -K << END >> $psfile
    38.477   141.190
END
gmt psxy -: -R $projection -Sl8p+t"260" -G0 -O -K << END >> $psfile
    38.750   140.790
END
gmt psxy -: -R $projection -Sl8p+t"261" -G0 -O -K << END >> $psfile
    38.940   140.930
END
gmt psxy -: -R $projection -Sl8p+t"262" -G0 -O -K << END >> $psfile
    38.802   140.843
END
gmt psxy -: -R $projection -Sl8p+t"263" -G0 -O -K << END >> $psfile
    39.099   140.883
END
gmt psxy -: -R $projection -Sl8p+t"264" -G0 -O -K << END >> $psfile
    38.752   140.787
END
gmt psxy -: -R $projection -Sl8p+t"265" -G0 -O -K << END >> $psfile
    39.192   140.958
END
gmt psxy -: -R $projection -Sl8p+t"266" -G0 -O -K << END >> $psfile
    39.180   140.972
END
gmt psxy -: -R $projection -Sl8p+t"267" -G0 -O -K << END >> $psfile
    38.868   140.884
END
gmt psxy -: -R $projection -Sl8p+t"268" -G0 -O -K << END >> $psfile
    38.511   141.084
END
gmt psxy -: -R $projection -Sl8p+t"269" -G0 -O -K << END >> $psfile
    38.466   140.207
END
gmt psxy -: -R $projection -Sl8p+t"270" -G0 -O -K << END >> $psfile
    39.053   140.876
END
gmt psxy -: -R $projection -Sl8p+t"271" -G0 -O -K << END >> $psfile
    38.626   140.643
END
gmt psxy -: -R $projection -Sl8p+t"272" -G0 -O -K << END >> $psfile
    39.038   140.893
END
gmt psxy -: -R $projection -Sl8p+t"273" -G0 -O -K << END >> $psfile
    39.080   140.959
END
gmt psxy -: -R $projection -Sl8p+t"274" -G0 -O -K << END >> $psfile
    38.941   140.587
END
gmt psxy -: -R $projection -Sl8p+t"275" -G0 -O -K << END >> $psfile
    39.027   140.934
END
gmt psxy -: -R $projection -Sl8p+t"276" -G0 -O -K << END >> $psfile
    39.215   140.791
END
gmt psxy -: -R $projection -Sl8p+t"277" -G0 -O -K << END >> $psfile
    39.208   140.805
END
gmt psxy -: -R $projection -Sl8p+t"278" -G0 -O -K << END >> $psfile
    39.203   140.798
END
gmt psxy -: -R $projection -Sl8p+t"279" -G0 -O -K << END >> $psfile
    38.875   140.891
END
gmt psxy -: -R $projection -Sl8p+t"280" -G0 -O -K << END >> $psfile
    38.927   140.616
END
gmt psxy -: -R $projection -Sl8p+t"281" -G0 -O -K << END >> $psfile
    38.622   140.640
END
gmt psxy -: -R $projection -Sl8p+t"282" -G0 -O -K << END >> $psfile
    39.042   140.859
END
gmt psxy -: -R $projection -Sl8p+t"283" -G0 -O -K << END >> $psfile
    38.819   140.829
END
gmt psxy -: -R $projection -Sl8p+t"284" -G0 -O -K << END >> $psfile
    39.153   140.975
END
gmt psxy -: -R $projection -Sl8p+t"285" -G0 -O -K << END >> $psfile
    38.992   140.793
END
gmt psxy -: -R $projection -Sl8p+t"286" -G0 -O -K << END >> $psfile
    38.972   140.933
END
gmt psxy -: -R $projection -Sl8p+t"287" -G0 -O -K << END >> $psfile
    38.274   141.554
END
gmt psxy -: -R $projection -Sl8p+t"288" -G0 -O -K << END >> $psfile
    38.696   140.993
END
gmt psxy -: -R $projection -Sl8p+t"289" -G0 -O -K << END >> $psfile
    39.073   140.925
END
gmt psxy -: -R $projection -Sl8p+t"290" -G0 -O -K << END >> $psfile
    39.055   140.873
END
gmt psxy -: -R $projection -Sl8p+t"291" -G0 -O -K << END >> $psfile
    39.052   140.872
END
gmt psxy -: -R $projection -Sl8p+t"292" -G0 -O -K << END >> $psfile
    38.890   140.351
END
gmt psxy -: -R $projection -Sl8p+t"293" -G0 -O -K << END >> $psfile
    39.052   140.879
END
gmt psxy -: -R $projection -Sl8p+t"294" -G0 -O -K << END >> $psfile
    39.053   140.888
END
gmt psxy -: -R $projection -Sl8p+t"295" -G0 -O -K << END >> $psfile
    39.057   140.898
END
gmt psxy -: -R $projection -Sl8p+t"296" -G0 -O -K << END >> $psfile
    38.308   141.565
END
gmt psxy -: -R $projection -Sl8p+t"297" -G0 -O -K << END >> $psfile
    38.985   140.918
END
gmt psxy -: -R $projection -Sl8p+t"298" -G0 -O -K << END >> $psfile
    39.065   140.892
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.726   141.140
    38.726   141.138
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.737   141.198
    38.726   141.138
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.723   141.139
    38.722   141.140
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.758   141.095
    38.722   141.140
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.731   141.173
    38.730   141.175
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.746   141.250
    38.730   141.175
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.728   141.143
    38.727   141.145
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.732   141.196
    38.727   141.145
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.709   141.130
    38.707   141.132
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.717   141.168
    38.707   141.132
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.733   141.179
    38.733   141.180
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.748   141.226
    38.733   141.180
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.690   141.139
    38.691   141.136
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.698   141.155
    38.691   141.136
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.685   141.076
    38.685   141.075
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.721   141.167
    38.685   141.075
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.231   140.714
    39.229   140.716
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.239   140.729
    39.229   140.716
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.281   140.723
    39.280   140.722
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.321   140.765
    39.280   140.722
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.251   140.829
    39.251   140.829
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.257   140.844
    39.251   140.829
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.719   141.121
    38.719   141.122
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.707   141.156
    38.719   141.122
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.687   140.650
    38.687   140.651
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.711   140.721
    38.687   140.651
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.776   140.806
    38.776   140.804
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.764   140.896
    38.776   140.804
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.680   141.157
    38.681   141.156
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.704   141.195
    38.681   141.156
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.687   141.202
    38.690   141.199
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.707   141.189
    38.690   141.199
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.161   140.827
    38.160   140.829
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.199   140.824
    38.160   140.829
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.773   140.688
    38.772   140.687
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.847   140.667
    38.772   140.687
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.775   141.030
    38.774   141.030
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.762   141.021
    38.774   141.030
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.566   141.764
    38.567   141.763
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.565   141.785
    38.567   141.763
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.714   141.081
    38.715   141.080
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.689   141.080
    38.715   141.080
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.727   141.193
    38.727   141.193
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.745   141.190
    38.727   141.193
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.977   140.459
    38.977   140.459
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.985   140.469
    38.977   140.459
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.417   140.671
    38.421   140.667
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.409   140.685
    38.421   140.667
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.964   141.007
    38.963   141.007
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.964   141.012
    38.963   141.007
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.988   140.977
    38.993   140.972
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.013   140.980
    38.993   140.972
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.890   140.724
    38.891   140.723
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.983   140.694
    38.891   140.723
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.887   140.735
    38.887   140.736
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.911   140.738
    38.887   140.736
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.772   141.125
    38.773   141.125
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.776   141.145
    38.773   141.125
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.052   140.953
    39.052   140.953
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.091   140.917
    39.052   140.953
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.055   140.958
    39.055   140.958
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.044   140.943
    39.055   140.958
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.003   140.961
    39.001   140.961
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.013   140.970
    39.001   140.961
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.766   141.146
    38.766   141.146
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.796   141.147
    38.766   141.146
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.297   140.832
    38.297   140.831
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.325   140.837
    38.297   140.831
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.311   140.536
    38.311   140.535
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.291   140.570
    38.311   140.535
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.802   141.208
    38.803   141.207
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.820   141.208
    38.803   141.207
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.939   140.649
    38.938   140.649
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.954   140.659
    38.938   140.649
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.956   141.001
    38.955   141.002
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.944   141.004
    38.955   141.002
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.696   141.065
    38.694   141.067
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.730   141.033
    38.694   141.067
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.670   141.116
    38.671   141.115
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.688   141.152
    38.671   141.115
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.823   140.738
    38.823   140.738
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.829   140.742
    38.823   140.738
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.827   140.751
    38.829   140.748
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.830   140.748
    38.829   140.748
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.491   140.348
    38.491   140.346
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.487   140.379
    38.491   140.346
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.768   141.172
    38.768   141.172
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.752   141.152
    38.768   141.172
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.838   141.031
    38.838   141.031
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.826   141.061
    38.838   141.031
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.479   140.818
    38.479   140.819
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.466   140.849
    38.479   140.819
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.044   140.970
    39.043   140.971
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.006   140.945
    39.043   140.971
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.874   140.843
    38.874   140.843
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.880   140.846
    38.874   140.843
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.886   140.820
    38.886   140.821
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.884   140.840
    38.886   140.821
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.879   140.841
    38.879   140.841
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.851   140.866
    38.879   140.841
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.881   140.824
    38.880   140.823
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.881   140.848
    38.880   140.823
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.829   140.618
    38.829   140.617
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.868   140.632
    38.829   140.617
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.867   140.640
    38.868   140.640
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.859   140.644
    38.868   140.640
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.870   140.640
    38.870   140.640
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.900   140.659
    38.870   140.640
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.827   140.642
    38.828   140.642
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.840   140.666
    38.828   140.642
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.876   140.638
    38.876   140.639
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.876   140.652
    38.876   140.639
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.890   140.621
    38.889   140.621
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.908   140.697
    38.889   140.621
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.874   140.657
    38.874   140.657
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.882   140.660
    38.874   140.657
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.895   140.655
    38.894   140.655
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.900   140.675
    38.894   140.655
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.846   140.634
    38.846   140.634
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.853   140.635
    38.846   140.634
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.936   140.679
    38.937   140.679
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.944   140.682
    38.937   140.679
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.905   140.617
    38.906   140.619
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.914   140.629
    38.906   140.619
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.879   140.651
    38.880   140.650
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.881   140.657
    38.880   140.650
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.856   140.628
    38.856   140.628
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.859   140.625
    38.856   140.628
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.869   140.647
    38.869   140.647
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.876   140.653
    38.869   140.647
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.902   140.610
    38.902   140.610
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.908   140.616
    38.902   140.610
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.834   140.644
    38.834   140.644
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.870   140.719
    38.834   140.644
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.858   140.633
    38.858   140.633
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.875   140.661
    38.858   140.633
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.848   140.643
    38.848   140.642
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.863   140.648
    38.848   140.642
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.889   140.647
    38.889   140.646
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.914   140.670
    38.889   140.646
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.862   140.687
    38.862   140.687
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.879   140.687
    38.862   140.687
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.820   140.645
    38.820   140.644
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.837   140.655
    38.820   140.644
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.828   140.645
    38.828   140.645
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.832   140.652
    38.828   140.645
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.836   140.633
    38.836   140.633
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.842   140.645
    38.836   140.633
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.816   140.649
    38.816   140.649
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.813   140.671
    38.816   140.649
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.857   140.679
    38.857   140.679
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.850   140.719
    38.857   140.679
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.907   140.683
    38.907   140.683
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.940   140.693
    38.907   140.683
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.867   140.672
    38.867   140.672
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.899   140.723
    38.867   140.672
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.884   140.666
    38.884   140.666
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.892   140.662
    38.884   140.666
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.950   140.580
    38.950   140.581
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.973   140.561
    38.950   140.581
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.883   140.663
    38.883   140.663
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.892   140.677
    38.883   140.663
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.959   140.572
    38.959   140.572
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.971   140.569
    38.959   140.572
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.960   140.574
    38.960   140.574
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.967   140.574
    38.960   140.574
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.812   140.586
    38.813   140.585
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.796   140.601
    38.813   140.585
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.807   140.592
    38.807   140.592
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.800   140.613
    38.807   140.592
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.909   140.618
    38.909   140.618
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.926   140.627
    38.909   140.618
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.810   140.588
    38.810   140.588
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.810   140.613
    38.810   140.588
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.895   140.625
    38.896   140.624
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.894   140.646
    38.896   140.624
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.893   140.645
    38.893   140.645
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.899   140.651
    38.893   140.645
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.903   140.633
    38.902   140.633
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.904   140.635
    38.902   140.633
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.865   140.674
    38.865   140.674
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.882   140.688
    38.865   140.674
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.888   140.650
    38.888   140.651
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.908   140.665
    38.888   140.651
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.888   140.675
    38.888   140.675
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.882   140.668
    38.888   140.675
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.865   140.644
    38.865   140.644
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.870   140.653
    38.865   140.644
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.888   140.613
    38.888   140.613
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.899   140.611
    38.888   140.613
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.851   140.695
    38.850   140.694
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.842   140.695
    38.850   140.694
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.885   141.024
    38.887   141.024
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.884   141.010
    38.887   141.024
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.271   140.767
    38.271   140.767
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.294   140.796
    38.271   140.767
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.290   140.751
    38.290   140.752
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.327   140.751
    38.290   140.752
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.274   140.768
    38.274   140.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.281   140.816
    38.274   140.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.785   140.727
    38.785   140.728
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.771   140.736
    38.785   140.728
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.282   140.769
    38.282   140.769
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.282   140.768
    38.282   140.769
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.018   140.933
    39.019   140.933
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.020   140.904
    39.019   140.933
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.875   141.026
    38.875   141.026
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.879   141.036
    38.875   141.026
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.874   140.683
    38.874   140.682
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.873   140.693
    38.874   140.682
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.024   140.924
    39.024   140.924
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.032   140.896
    39.024   140.924
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.018   140.925
    39.018   140.925
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.018   140.913
    39.018   140.925
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.022   140.915
    39.022   140.915
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.028   140.914
    39.022   140.915
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.983   140.965
    38.983   140.965
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.985   140.979
    38.983   140.965
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.758   140.702
    38.758   140.701
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.744   140.721
    38.758   140.701
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.609   141.144
    38.609   141.144
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.586   141.146
    38.609   141.144
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.770   141.128
    38.770   141.128
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.720   141.171
    38.770   141.128
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.714   141.134
    38.714   141.134
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.708   141.127
    38.714   141.134
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.472   140.530
    38.472   140.530
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.495   140.528
    38.472   140.530
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.045   140.977
    39.045   140.978
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.085   141.006
    39.045   140.978
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.435   141.162
    38.435   141.162
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.436   141.141
    38.435   141.162
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.397   141.155
    38.397   141.155
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.368   141.120
    38.397   141.155
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.426   141.165
    38.426   141.165
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.430   141.136
    38.426   141.165
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.469   141.165
    38.469   141.165
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.461   141.127
    38.469   141.165
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.471   141.167
    38.471   141.166
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.508   141.187
    38.471   141.166
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.414   141.203
    38.420   141.201
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.466   141.177
    38.420   141.201
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.485   141.177
    38.485   141.177
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.502   141.169
    38.485   141.177
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.469   141.188
    38.469   141.187
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.496   141.170
    38.469   141.187
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.478   141.222
    38.478   141.222
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.460   141.194
    38.478   141.222
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.473   141.168
    38.473   141.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.447   141.142
    38.473   141.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.475   141.159
    38.476   141.159
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.452   141.149
    38.476   141.159
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.428   141.194
    38.428   141.194
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.375   141.186
    38.428   141.194
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.497   141.207
    38.497   141.207
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.518   141.202
    38.497   141.207
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.509   141.188
    38.508   141.186
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.513   141.082
    38.508   141.186
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.486   141.212
    38.486   141.212
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.495   141.188
    38.486   141.212
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.474   141.169
    38.474   141.169
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.450   141.157
    38.474   141.169
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.393   141.170
    38.392   141.171
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.393   141.141
    38.392   141.171
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.530   141.229
    38.530   141.229
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.498   141.176
    38.530   141.229
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.463   141.177
    38.463   141.177
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.451   141.161
    38.463   141.177
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.507   141.180
    38.507   141.180
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.503   141.152
    38.507   141.180
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.049   140.975
    39.049   140.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.030   140.953
    39.049   140.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.475   141.163
    38.474   141.163
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.469   141.141
    38.474   141.163
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.492   141.192
    38.493   141.192
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.488   141.175
    38.493   141.192
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.390   141.168
    38.390   141.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.401   141.178
    38.390   141.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.461   141.215
    38.461   141.215
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.476   141.204
    38.461   141.215
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.083   140.851
    39.083   140.850
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.032   140.793
    39.083   140.850
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.975   140.627
    38.975   140.627
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.963   140.617
    38.975   140.627
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.392   140.749
    38.392   140.749
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.377   140.718
    38.392   140.749
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.202   141.173
    38.202   141.173
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.180   141.163
    38.202   141.173
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.200   141.155
    38.200   141.154
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.191   141.175
    38.200   141.154
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.422   141.123
    38.422   141.123
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.407   141.119
    38.422   141.123
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.985   140.601
    38.985   140.600
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.994   140.610
    38.985   140.600
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.047   140.876
    39.047   140.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.037   140.819
    39.047   140.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.117   140.957
    39.117   140.957
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.112   140.977
    39.117   140.957
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.113   141.039
    39.113   141.039
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.100   140.968
    39.113   141.039
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.144   140.954
    39.144   140.954
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.131   140.948
    39.144   140.954
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.903   140.904
    38.901   140.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.897   140.882
    38.901   140.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.017   140.887
    39.017   140.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.006   140.871
    39.017   140.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.106   140.901
    39.107   140.901
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.081   140.915
    39.107   140.901
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.821   140.833
    38.821   140.833
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.839   140.808
    38.821   140.833
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.143   140.944
    39.143   140.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.140   140.943
    39.143   140.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.896   140.703
    38.896   140.703
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.890   140.647
    38.896   140.703
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.030   140.897
    39.030   140.897
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.018   140.882
    39.030   140.897
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.905   140.739
    38.905   140.739
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.847   140.760
    38.905   140.739
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.093   140.949
    39.092   140.948
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.097   140.892
    39.092   140.948
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.125   140.978
    39.125   140.978
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.103   140.980
    39.125   140.978
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.043   140.942
    39.043   140.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.020   140.921
    39.043   140.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.909   140.892
    38.909   140.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.894   140.879
    38.909   140.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.070   141.037
    39.070   141.037
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.075   140.956
    39.070   141.037
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.088   140.904
    39.088   140.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.104   140.920
    39.088   140.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.078   141.011
    39.078   141.011
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.066   140.990
    39.078   141.011
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.102   140.891
    39.102   140.891
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.088   140.861
    39.102   140.891
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.029   140.908
    39.028   140.909
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.020   140.873
    39.028   140.909
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.107   140.954
    39.107   140.954
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.099   140.949
    39.107   140.954
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.940   140.910
    38.940   140.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.934   140.886
    38.940   140.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.108   140.956
    39.108   140.956
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.090   140.963
    39.108   140.956
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.871   140.895
    38.871   140.894
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.869   140.873
    38.871   140.894
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.879   140.887
    38.879   140.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.870   140.876
    38.879   140.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.104   140.918
    39.104   140.917
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.087   140.853
    39.104   140.917
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.061   140.972
    39.060   140.972
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.081   140.880
    39.060   140.972
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.140   140.967
    39.140   140.967
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.148   140.891
    39.140   140.967
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.999   140.932
    38.999   140.932
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.974   140.914
    38.999   140.932
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.096   140.889
    39.096   140.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.108   140.855
    39.096   140.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.058   140.881
    39.059   140.882
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.037   140.867
    39.059   140.882
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.109   140.951
    39.109   140.951
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.100   140.959
    39.109   140.951
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.117   140.965
    39.117   140.965
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.131   140.909
    39.117   140.965
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.973   140.916
    38.973   140.916
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.968   140.915
    38.973   140.916
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.108   140.975
    39.108   140.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.080   140.998
    39.108   140.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.142   140.943
    39.142   140.943
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.136   140.917
    39.142   140.943
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.860   140.883
    38.860   140.883
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.857   140.864
    38.860   140.883
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.871   140.785
    38.871   140.785
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.890   140.778
    38.871   140.785
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.127   140.928
    39.127   140.928
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.126   140.934
    39.127   140.928
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.124   140.934
    39.124   140.934
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.118   140.888
    39.124   140.934
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.896   140.787
    38.896   140.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.898   140.775
    38.896   140.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.149   140.955
    39.149   140.955
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.154   140.948
    39.149   140.955
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.978   140.957
    38.977   140.958
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.997   140.871
    38.977   140.958
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.013   140.967
    39.013   140.967
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.009   140.992
    39.013   140.967
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.086   140.999
    39.086   140.999
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.089   140.971
    39.086   140.999
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.878   140.791
    38.878   140.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.870   140.783
    38.878   140.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.156   140.878
    39.156   140.878
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.149   140.846
    39.156   140.878
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.159   140.969
    39.159   140.969
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.171   140.955
    39.159   140.969
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.788   140.807
    38.788   140.807
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.795   140.810
    38.788   140.807
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.755   140.798
    38.755   140.798
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.757   140.796
    38.755   140.798
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.126   140.932
    39.126   140.932
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.083   140.931
    39.126   140.932
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.164   140.985
    39.165   140.986
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.163   140.956
    39.165   140.986
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.129   140.923
    39.129   140.923
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.096   140.908
    39.129   140.923
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.145   140.969
    39.145   140.969
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.102   140.944
    39.145   140.969
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.105   140.944
    39.105   140.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.098   140.950
    39.105   140.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.127   140.947
    39.127   140.947
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.128   140.966
    39.127   140.947
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.157   140.960
    39.158   140.960
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.160   140.977
    39.158   140.960
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.186   140.978
    39.186   140.977
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.182   140.957
    39.186   140.977
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.987   140.791
    38.987   140.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.044   140.801
    38.987   140.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.914   140.871
    38.914   140.871
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.910   140.878
    38.914   140.871
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.060   140.803
    39.060   140.803
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.047   140.794
    39.060   140.803
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.088   140.963
    39.088   140.963
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.099   140.955
    39.088   140.963
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.133   140.966
    39.134   140.966
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.113   140.966
    39.134   140.966
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.153   140.959
    39.153   140.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.142   140.957
    39.153   140.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.791   140.801
    38.791   140.801
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.783   140.811
    38.791   140.801
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.902   140.591
    38.902   140.591
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.909   140.601
    38.902   140.591
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.834   140.846
    38.834   140.846
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.822   140.831
    38.834   140.846
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.103   140.968
    39.103   140.968
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.085   140.959
    39.103   140.968
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.167   140.984
    39.167   140.984
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.153   140.991
    39.167   140.984
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.043   140.891
    39.043   140.891
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.041   140.892
    39.043   140.891
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.101   140.947
    39.100   140.947
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.116   140.941
    39.100   140.947
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.046   140.910
    39.046   140.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.053   140.913
    39.046   140.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.164   140.974
    39.164   140.974
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.148   140.974
    39.164   140.974
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.171   140.974
    39.171   140.974
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.171   140.961
    39.171   140.974
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.940   140.921
    38.940   140.921
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.924   140.904
    38.940   140.921
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.119   141.006
    39.119   141.006
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.098   141.007
    39.119   141.006
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.038   140.899
    39.038   140.899
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.038   140.887
    39.038   140.899
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.856   140.831
    38.856   140.831
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.838   140.835
    38.856   140.831
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.080   140.975
    39.080   140.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.093   140.913
    39.080   140.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.749   140.792
    38.749   140.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.745   140.747
    38.749   140.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.742   140.779
    38.742   140.779
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.734   140.788
    38.742   140.779
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.751   140.762
    38.751   140.762
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.751   140.719
    38.751   140.762
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.734   140.791
    38.734   140.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.739   140.793
    38.734   140.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.742   140.792
    38.743   140.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.734   140.801
    38.743   140.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.880   140.757
    38.880   140.757
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.880   140.760
    38.880   140.757
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.949   140.665
    38.949   140.665
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.945   140.640
    38.949   140.665
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.110   140.970
    39.110   140.970
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.116   140.999
    39.110   140.970
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.065   140.968
    39.065   140.968
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.046   140.960
    39.065   140.968
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.874   140.785
    38.874   140.785
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.855   140.795
    38.874   140.785
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.164   140.860
    39.164   140.860
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.151   140.812
    39.164   140.860
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.128   140.915
    39.129   140.915
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.108   140.885
    39.129   140.915
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.111   140.877
    39.111   140.877
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.095   140.879
    39.111   140.877
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.001   140.895
    39.001   140.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.985   140.888
    39.001   140.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.980   140.841
    38.981   140.841
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.982   140.812
    38.981   140.841
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.955   140.930
    38.955   140.931
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.937   140.917
    38.955   140.931
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.059   140.874
    39.060   140.875
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.040   140.827
    39.060   140.875
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.073   140.822
    39.075   140.818
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.048   140.806
    39.075   140.818
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.057   140.890
    39.057   140.890
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.052   140.879
    39.057   140.890
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.821   140.860
    38.821   140.860
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.815   140.848
    38.821   140.860
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.175   140.853
    39.175   140.853
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.167   140.828
    39.175   140.853
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.129   140.952
    39.129   140.952
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.104   140.932
    39.129   140.952
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.145   140.942
    39.145   140.942
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.144   140.955
    39.145   140.942
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.150   140.883
    39.150   140.883
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.140   140.890
    39.150   140.883
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.892   140.970
    38.892   140.970
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.889   140.951
    38.892   140.970
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.869   140.887
    38.869   140.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.841   140.876
    38.869   140.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.753   140.805
    38.753   140.804
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.733   140.776
    38.753   140.804
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.053   140.895
    39.053   140.895
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.040   140.905
    39.053   140.895
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.864   140.749
    38.864   140.749
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.841   140.746
    38.864   140.749
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.793   140.791
    38.793   140.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.739   140.916
    38.793   140.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.898   140.813
    38.898   140.813
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.896   140.816
    38.898   140.813
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.477   141.190
    38.477   141.190
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.468   141.171
    38.477   141.190
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.750   140.790
    38.750   140.790
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.717   140.794
    38.750   140.790
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.940   140.930
    38.940   140.930
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.930   140.911
    38.940   140.930
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.802   140.843
    38.802   140.843
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.800   140.834
    38.802   140.843
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.099   140.882
    39.099   140.883
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.102   140.892
    39.099   140.883
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.752   140.787
    38.752   140.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.736   140.836
    38.752   140.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.191   140.958
    39.192   140.958
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.175   140.954
    39.192   140.958
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.180   140.973
    39.180   140.972
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.160   140.927
    39.180   140.972
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.868   140.884
    38.868   140.884
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.855   140.859
    38.868   140.884
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.511   141.084
    38.511   141.084
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.523   141.047
    38.511   141.084
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.466   140.207
    38.466   140.207
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.483   140.305
    38.466   140.207
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.053   140.876
    39.053   140.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.095   140.820
    39.053   140.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.622   140.643
    38.626   140.643
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.616   140.691
    38.626   140.643
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.038   140.893
    39.038   140.893
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.031   140.892
    39.038   140.893
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.080   140.959
    39.080   140.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.023   140.936
    39.080   140.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.941   140.587
    38.941   140.587
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.922   140.660
    38.941   140.587
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.027   140.934
    39.027   140.934
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.037   140.909
    39.027   140.934
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.215   140.791
    39.215   140.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.166   140.733
    39.215   140.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.208   140.805
    39.208   140.805
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.217   141.001
    39.208   140.805
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.203   140.798
    39.203   140.798
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.207   140.874
    39.203   140.798
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.875   140.891
    38.875   140.891
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.862   140.872
    38.875   140.891
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.927   140.616
    38.927   140.616
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.927   140.607
    38.927   140.616
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.622   140.640
    38.622   140.640
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.631   140.660
    38.622   140.640
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.042   140.859
    39.042   140.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.034   140.860
    39.042   140.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.819   140.829
    38.819   140.829
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.803   140.831
    38.819   140.829
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.153   140.974
    39.153   140.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.144   140.946
    39.153   140.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.992   140.793
    38.992   140.793
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.919   140.545
    38.992   140.793
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.972   140.933
    38.972   140.933
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.963   140.906
    38.972   140.933
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.274   141.554
    38.274   141.554
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.287   141.527
    38.274   141.554
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.696   140.993
    38.696   140.993
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.692   140.989
    38.696   140.993
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.073   140.925
    39.073   140.925
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.081   140.934
    39.073   140.925
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.055   140.873
    39.055   140.873
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.074   140.896
    39.055   140.873
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.052   140.872
    39.052   140.872
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.071   140.867
    39.052   140.872
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.890   140.351
    38.890   140.351
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.901   140.453
    38.890   140.351
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.052   140.879
    39.052   140.879
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.037   140.860
    39.052   140.879
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.053   140.888
    39.053   140.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.077   140.938
    39.053   140.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.057   140.898
    39.057   140.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.076   140.926
    39.057   140.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.308   141.566
    38.308   141.565
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.306   141.532
    38.308   141.565
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.985   140.918
    38.985   140.918
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.963   140.888
    38.985   140.918
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.064   140.892
    39.065   140.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.086   140.974
    39.065   140.892
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    38.726   141.138     8.818     0.955     1.810
    38.722   141.140    35.296     1.420     2.413
    38.730   141.175    20.921     1.636     2.818
    38.727   141.145    32.625     1.343     2.173
    38.707   141.132    33.099     1.572     2.547
    38.733   141.180    26.221     1.409     2.003
    38.691   141.136    19.752     1.857     3.457
    38.685   141.075    22.573     1.697     2.819
    39.229   140.716    12.142     0.950     1.416
    39.280   140.722   -19.197     1.665     2.148
    39.251   140.829   -47.843     2.029     3.103
    38.719   141.122    37.008     1.622     2.591
    38.687   140.651    27.085     1.521     1.763
    38.776   140.804    42.698     1.631     2.391
    38.681   141.156    21.522     2.121     3.019
    38.690   141.199    28.959     1.854     3.125
    38.160   140.829    52.354     1.419     2.795
    38.772   140.687    15.101     1.184     1.501
    38.774   141.030    43.727     1.208     2.000
    38.567   141.763    21.818     1.386     2.745
    38.715   141.080    44.208     1.466     2.285
    38.727   141.193    39.721     1.301     2.297
    38.977   140.459    10.492     1.523     2.069
    38.421   140.667    58.542     1.308     2.836
    38.963   141.007    35.223     1.157     1.405
    38.993   140.972    53.138     1.210     1.610
    38.891   140.723    23.846     1.125     1.614
    38.887   140.736    17.521     1.290     1.587
    38.773   141.125    40.427     1.008     1.758
    39.052   140.953    18.446     1.046     1.312
    39.055   140.958    55.022     1.401     1.589
    39.001   140.961    69.208     1.495     1.740
    38.766   141.146    35.624     1.125     1.575
    38.297   140.831    49.047     1.085     2.188
    38.311   140.535    44.720     1.063     1.789
    38.803   141.207    34.616     0.950     1.814
    38.938   140.649    24.603     1.111     1.672
    38.955   141.002    45.949     1.160     1.816
    38.694   141.067    38.008     1.118     1.787
    38.671   141.115    33.991     1.005     1.775
    38.823   140.738    36.906     0.910     1.420
    38.829   140.748    38.682     1.399     2.121
    38.491   140.346    34.738     1.220     2.208
    38.768   141.172    33.516     0.881     1.639
    38.838   141.031    38.460     0.985     1.741
    38.479   140.819    24.899     0.960     1.660
    39.043   140.971    30.922     1.070     1.904
    38.874   140.843    25.278     0.980     1.889
    38.886   140.821    34.595     1.047     2.204
    38.879   140.841    33.654     1.091     1.853
    38.880   140.823    30.739     0.845     1.462
    38.829   140.617    35.674     0.833     1.469
    38.868   140.640    42.692     1.391     2.262
    38.870   140.640    51.775     1.077     1.846
    38.828   140.642    41.816     0.905     1.940
    38.876   140.639    35.890     0.718     1.339
    38.889   140.621    44.155     1.034     2.209
    38.874   140.657    40.965     0.732     1.338
    38.894   140.655    39.009     0.544     1.166
    38.846   140.634    41.469     0.919     1.536
    38.937   140.679    51.177     1.070     2.029
    38.906   140.619    39.710     0.823     1.439
    38.880   140.650    39.081     0.828     1.411
    38.856   140.628    39.052     0.697     1.134
    38.869   140.647    43.032     0.784     1.305
    38.902   140.610    41.172     1.043     1.700
    38.834   140.644    41.110     0.871     1.560
    38.858   140.633    38.844     0.705     1.456
    38.848   140.642    42.658     0.771     1.549
    38.889   140.646    40.347     0.774     1.547
    38.862   140.687    41.388     0.702     1.418
    38.820   140.644    42.396     0.773     1.353
    38.828   140.645    37.226     0.748     1.297
    38.836   140.633    40.299     0.721     1.509
    38.816   140.649    34.722     0.760     1.324
    38.857   140.679    38.703     0.730     1.616
    38.907   140.683    42.409     0.895     1.750
    38.867   140.672    39.121     0.673     1.381
    38.884   140.666    37.407     0.726     1.253
    38.950   140.581    36.440     0.755     1.471
    38.883   140.663    40.089     0.703     1.267
    38.959   140.572    38.547     0.897     1.574
    38.960   140.574    38.101     0.890     1.481
    38.813   140.585    35.040     0.661     1.071
    38.807   140.592    34.822     0.715     1.193
    38.909   140.618    37.946     0.874     1.311
    38.810   140.588    35.717     0.749     1.283
    38.896   140.624    41.223     0.862     1.655
    38.893   140.645    39.675     0.737     1.335
    38.902   140.633    40.424     0.702     1.326
    38.865   140.674    39.534     0.776     1.350
    38.888   140.651    40.058     0.837     1.547
    38.888   140.675    35.685     1.009     1.829
    38.865   140.644    30.406     0.761     1.417
    38.888   140.613    35.720     0.733     1.194
    38.850   140.694    38.846     1.205     1.983
    38.887   141.024    31.218     1.175     1.861
    38.271   140.767    13.103     1.551     1.696
    38.290   140.752    31.064     1.346     1.604
    38.274   140.768    14.345     1.617     1.758
    38.785   140.728    58.159     1.367     1.888
    38.282   140.769   -39.696     1.858     1.986
    39.019   140.933    66.556     1.183     1.313
    38.875   141.026    32.613     1.357     2.086
    38.874   140.682    73.454     1.293     1.479
    39.024   140.924    68.595     0.924     1.109
    39.018   140.925    66.935     0.949     1.095
    39.022   140.915    63.356     1.289     1.562
    38.983   140.965    54.599     0.873     1.007
    38.758   140.701    54.846     1.570     2.599
    38.609   141.144    25.045     1.604     2.303
    38.770   141.128    18.674     1.724     3.170
    38.714   141.134     7.923     1.619     2.583
    38.472   140.530    88.335     1.523     2.572
    39.045   140.978     7.547     1.879     2.599
    38.435   141.162    58.552     1.078     2.128
    38.397   141.155    29.114     1.396     2.317
    38.426   141.165    57.893     0.884     1.621
    38.469   141.165    71.160     2.543     3.618
    38.471   141.166    71.385     2.275     2.904
    38.420   141.201    62.320     2.377     4.423
    38.485   141.177    34.410     2.015     2.585
    38.469   141.187    79.615     1.696     2.970
    38.478   141.222    54.485     1.940     2.744
    38.473   141.168    51.788     2.401     2.918
    38.476   141.159    53.294     2.691     3.193
    38.428   141.194    65.194     3.014     5.154
    38.497   141.207    54.448     1.931     2.585
    38.508   141.186    48.505     0.900     1.443
    38.486   141.212    46.345     2.188     2.334
    38.474   141.169    57.713     1.134     2.241
    38.392   141.171    62.266     1.713     3.712
    38.530   141.229    41.595     1.405     1.877
    38.463   141.177    58.832     1.864     3.014
    38.507   141.180    46.288     1.617     2.349
    39.049   140.975     4.622     1.979     2.780
    38.474   141.163    47.235     1.797     2.840
    38.493   141.192    56.279     1.537     2.191
    38.390   141.168    53.892     1.974     3.699
    38.461   141.215    45.940     1.638     2.809
    39.083   140.850   -67.551     2.106     3.055
    38.975   140.627    52.656     1.528     2.433
    38.392   140.749     7.263     1.557     1.625
    38.202   141.173    24.076     1.389     2.339
    38.200   141.154    52.214     2.164     4.072
    38.422   141.123    67.459     1.759     3.793
    38.985   140.600    55.653     1.272     1.660
    39.047   140.876    54.838     0.594     0.929
    39.117   140.957     7.210     1.686     2.305
    39.113   141.039    -8.664     1.600     2.043
    39.144   140.954   -22.822     1.865     2.305
    38.901   140.905    60.074     1.428     2.049
    39.017   140.887    38.295     1.786     2.262
    39.107   140.901   -36.648     1.521     2.080
    38.821   140.833    40.937     1.656     2.787
    39.143   140.944    -4.761     1.741     2.072
    38.896   140.703    67.887     0.957     1.321
    39.030   140.897   -18.829     2.035     2.769
    38.905   140.739   -87.182     1.781     1.970
    39.092   140.948   -80.563     1.447     1.600
    39.125   140.978    10.137     1.833     2.530
    39.043   140.941    52.909     1.282     1.572
    38.909   140.892    49.288     1.239     1.833
    39.070   141.037   -49.917     1.692     2.159
    39.088   140.905   -28.898     2.263     2.962
    39.078   141.011    -7.381     1.585     1.969
    39.102   140.891     7.057     2.293     2.620
    39.028   140.909    44.163     1.116     1.381
    39.107   140.954    -2.101     1.891     2.442
    38.940   140.910    50.685     1.119     1.632
    39.108   140.956    -1.888     1.897     2.356
    38.871   140.894    43.827     1.169     1.739
    38.879   140.887    80.218     2.695     2.989
    39.104   140.917   -68.831     1.286     1.564
    39.060   140.972   -72.522     2.147     2.292
    39.140   140.967    64.480     0.917     1.112
    38.999   140.932   -83.525     2.913     3.656
    39.096   140.888   -71.008     1.407     1.529
    39.059   140.882   -56.876     1.695     1.920
    39.109   140.951    11.408     1.589     1.979
    39.117   140.965    -1.771     1.552     1.589
    38.973   140.916    57.634     2.002     2.387
    39.108   140.975   -47.107     2.748     2.803
    39.142   140.943   -13.511     1.227     1.376
    38.860   140.883    47.643     1.203     2.072
    38.871   140.785    46.709     1.399     2.192
    39.127   140.928    18.357     2.235     2.726
    39.124   140.934   -47.899     1.408     1.476
    38.896   140.787    44.264     1.148     1.660
    39.149   140.955    -5.526     1.605     1.953
    38.977   140.958    63.021     1.044     1.642
    39.013   140.967    35.514     1.764     2.342
    39.086   140.999    -2.622     1.263     1.521
    38.878   140.791    49.607     1.298     2.058
    39.156   140.878    -7.811     1.317     1.566
    39.159   140.969   -17.999     1.282     1.498
    38.788   140.807    43.187     1.547     2.167
    38.755   140.798    47.663     1.180     1.680
    39.126   140.932    17.895     2.444     3.070
    39.165   140.986    59.278     1.448     1.542
    39.129   140.923     9.944     1.562     2.069
    39.145   140.969   -24.397     2.153     2.869
    39.105   140.944     1.463     1.197     1.497
    39.127   140.947     6.807     1.195     1.683
    39.158   140.960     4.887     1.935     2.717
    39.186   140.977     7.601     1.897     2.235
    38.987   140.791    38.217     1.296     1.881
    38.914   140.871    45.410     1.061     1.531
    39.060   140.803    51.936     1.699     2.360
    39.088   140.963    -0.769     1.364     1.622
    39.134   140.966   -14.999     1.163     1.274
    39.153   140.959     8.152     2.030     2.928
    38.791   140.801    46.091     1.442     2.288
    38.902   140.591    55.401     1.182     1.843
    38.834   140.846    22.430     1.317     1.627
    39.103   140.968    -1.911     1.446     1.897
    39.167   140.984    10.044     1.374     1.706
    39.043   140.891    37.531     1.332     1.740
    39.100   140.947   -75.354     1.113     1.162
    39.046   140.910    23.819     1.284     1.503
    39.164   140.974     9.786     1.499     1.855
    39.171   140.974     5.679     1.486     2.009
    38.940   140.921    46.147     1.165     1.867
    39.119   141.006    -3.384     2.219     3.041
    39.038   140.899    39.304     1.501     1.972
    38.856   140.831    41.171     1.409     2.068
    39.080   140.975   -54.513     1.087     1.128
    38.749   140.792    50.471     1.200     1.700
    38.742   140.779    46.255     1.000     1.494
    38.751   140.762    55.797     0.864     1.301
    38.734   140.791    49.292     1.083     1.662
    38.743   140.792    47.882     1.117     1.595
    38.880   140.757    48.071     1.251     1.751
    38.949   140.665    50.373     0.870     1.258
    39.110   140.970     2.784     1.515     2.095
    39.065   140.968     0.062     1.251     1.648
    38.874   140.785    50.796     1.448     2.280
    39.164   140.860    -5.222     1.948     2.316
    39.129   140.915    -1.999     1.546     1.806
    39.111   140.877    -9.036     2.015     2.109
    39.001   140.896    38.300     1.339     1.804
    38.981   140.841    40.781     1.569     2.133
    38.955   140.931    40.734     1.339     1.837
    39.060   140.875    47.605     1.556     1.696
    39.075   140.818    57.933     1.409     1.863
    39.057   140.890     8.472     1.728     2.200
    38.821   140.860    43.823     1.312     2.053
    39.175   140.853    21.286     1.601     1.866
    39.129   140.952    -2.625     1.511     1.875
    39.145   140.942     7.439     1.552     2.181
    39.150   140.883    16.760     2.073     2.525
    38.892   140.970    41.996     1.402     2.207
    38.869   140.887    43.845     1.165     1.815
    38.753   140.804    62.079     1.794     2.302
    39.053   140.895     4.696     1.761     2.069
    38.864   140.749    50.750     1.409     2.334
    38.793   140.791    49.271     1.270     2.052
    38.898   140.813    48.823     1.164     2.439
    38.477   141.190    47.041     1.571     2.282
    38.750   140.790    46.411     1.471     2.311
    38.940   140.930    49.908     1.449     2.183
    38.802   140.843    46.759     1.580     2.436
    39.099   140.883     9.859     1.507     2.078
    38.752   140.787    54.194     1.304     1.960
    39.192   140.958     5.690     1.718     2.237
    39.180   140.972    10.828     1.820     2.251
    38.868   140.884    43.930     1.128     1.874
    38.511   141.084    49.974     1.290     1.937
    38.466   140.207    72.291     1.435     2.085
    39.053   140.876   -12.789     1.537     1.959
    38.626   140.643    53.487     1.463     2.152
    39.038   140.893    63.412     1.417     1.529
    39.080   140.959     3.907     1.350     1.558
    38.941   140.587    52.225     1.269     2.151
    39.027   140.934    56.956     0.806     1.139
    39.215   140.791    -5.350     1.973     2.644
    39.208   140.805    -4.361     2.174     2.928
    39.203   140.798     6.800     1.538     2.139
    38.875   140.891    39.432     1.048     1.450
    38.927   140.616    57.635     1.323     1.979
    38.622   140.640    55.584     1.210     1.794
    39.042   140.859   -82.806     1.435     1.551
    38.819   140.829    43.426     1.288     2.260
    39.153   140.975     8.942     1.592     2.145
    38.992   140.793   -73.854     0.889     3.129
    38.972   140.933    37.505     1.253     1.628
    38.274   141.554    17.976     1.407     3.814
    38.696   140.993    52.775     1.261     1.935
    39.073   140.925   -33.644     1.167     1.371
    39.055   140.873   -10.042     1.381     1.658
    39.052   140.872    -8.137     1.534     1.930
    38.890   140.351    55.211     1.253     2.303
    39.052   140.879    78.621     1.488     1.596
    39.053   140.888   -20.166     1.164     1.390
    39.057   140.898   -16.902     2.262     2.887
    38.308   141.565    11.828     1.621     4.405
    38.985   140.918    84.566     1.147     1.388
    39.065   140.892   -26.574     1.801     2.231
END

# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    38.726   141.138     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    39.229   140.716     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    38.829   140.617     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    38.426   141.165     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    39.047   140.876     0.300
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    38.114   140.176    55.066     0.574     0.705
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    38.114   140.198   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    38.114   140.176     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    38.114   140.176     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    38.069   140.176   5 km
END
